@@ -30,7 +30,7 @@ struct apk_db_acl {
 	uid_t uid;
 	gid_t gid;
 	uint8_t xattr_hash_len;
-	uint8_t xattr_hash[];
+	uint8_t xattr_hash[] __attribute__((counted_by(xattr_hash_len)));
 } __attribute__((packed));
 
 static inline apk_blob_t apk_acl_digest_blob(struct apk_db_acl *acl) {
@@ -197,7 +197,7 @@ struct apk_database {
 	unsigned int active_layers;
 	unsigned int num_dir_update_errors;
 
-	unsigned int script_memfd_ok : 1;
+	unsigned int memfd_failed : 1;
 	unsigned int performing_preupgrade : 1;
 	unsigned int usermode : 1;
 	unsigned int root_tmpfs : 1;
